@@ -19,6 +19,9 @@ public:
     explicit KCalcBitset(QWidget *parent = nullptr);
     Q_REQUIRED_RESULT quint64 getValue() const;
 
+protected:
+    void resizeEvent(QResizeEvent *event) override;
+
 public Q_SLOTS:
     void setValue(quint64 value);
     void slotToggleBit(QAbstractButton *button);
@@ -29,5 +32,6 @@ Q_SIGNALS:
 private:
     QButtonGroup *const bit_button_group_;
     quint64 value_;
+    float ratio_;
 };
 
